@@ -26,7 +26,7 @@ import socket
 
 
 # The current version of duplicity
-version = "0.7.07.1"
+version = "0.7.12"
 
 # Prefix for all files (appended before type-specific prefixes)
 file_prefix = ""
@@ -153,8 +153,8 @@ encryption = True
 # If set to false, then do not compress files on remote system
 compression = True
 
-# volume size. default 25M
-volsize = 25 * 1024 * 1024
+# volume size. default 200M
+volsize = 200 * 1024 * 1024
 
 # Working directory for the tempfile module. Defaults to /tmp on most systems.
 temproot = None
@@ -274,6 +274,10 @@ rename = {}
 # enable data comparison on verify runs
 compare_data = False
 
+# When symlinks are encountered, the item they point to is copied rather than
+# the symlink.
+copy_links = False
+
 # When selected, triggers a dry-run before a full or incremental to compute
 # changes, then runs the real operation and keeps track of the real progress
 progress = False
@@ -293,3 +297,6 @@ use_gio = False
 
 # If set, collect only the file status, not the whole root.
 file_changed = None
+
+# delay (in seconds) before next operation after failure
+backend_retry_delay = 30
